    
          FragmentationFlavZpT
          ==================== 

This set of classes handles a few auxiliary tasks of the fragmentation 
framework: the choice of new flavours and the formation of hadrons, the
choice of a fragmentation pT and of a longitudinal lightcone fraction.
These are mainly used in the StringFragmentation class, but also partly
in MiniStringFragmentation, ParticleDecays and BeamParticle classes, 
which is the reason they have been broken out and put separately.
The basic physics principles are outlined e.g. in [1].

---------------------------------------------------------------------- 

   The StringFlav class
   --------------------

This class handles the choice of a new flavour in the fragmentation 
process, and the production of a new hadron from a set of input 
flavours. Currently only simple diquark production of baryons is
included; the more sophisticated popcorn scenario remains to be 
implemented.

The main parameters of the selection of a new flavour are

<parameter> StringFlav:probQQtoQ = 0.10 min = 0.0 max = 1.0
the suppression of diquark production relative to quark production,
i.e. of baryon relative to meson production.

<parameter> StringFlav:probStoU = 0.30 min = 0.0 max = 1.0
the suppression of s quark production relative to ordinary u or d one.

<parameter> StringFlav:probSQtoQQ = 0.4 min = 0.0 max = 1.0
the suppression of strange diquark production relative to light
diquark production, over and above the one already given by probStoU.
 
<parameter> StringFlav:probQQ1toQQ0 = 0.05 min = 0.0 max = 1.0
the suppression of spin 1 diquark production relative to spin 0 one,
apart from the factor of 3 enhancement of spin 0 from counting the
number of states.

For a given set of flavours,the main parameters for meson production
are
<parameter> StringFlav:mesonUspin1 = 0.50 min = 0. max = 1.
<parameter> StringFlav:mesonSspin1 = 0.60 min = 0. max = 1.
<parameter> StringFlav:mesonCspin1 = 0.70 min = 0. max = 1.
<parameter> StringFlav:mesonBspin1 = 0.75 min = 0. max = 1.
which represent the relative fraction of light (u, d), strange, 
charm and bottom mesons, respectively, that are chosen to have 
spin 1, i.e. be vectors, with the remainder having spin 0, i.e. 
pseudoscalars. 

Inside each light-quark meson nonet, an octet-singlet mixing angle
describes the mixing of the two flavour-diagonal isoscalar = 0 states.
(For terminology and details see [2], chapter 14 on the quark model.)
This angle is needed to specify the probability for such a qqbar state
to project onto a specific meson. More transparent formuale are 
obtained by introducing the angle alpha = theta + 54.7 degrees:
  f  = (uubar + ddbar)/sqrt(2) * sin(alpha) + ssbar * cos(alpha)  
  f' = (uubar + ddbar)/sqrt(2) * cos(alpha) - ssbar * sin(alpha)

<parameter> StringFlav:thetaPS = -15. min = -90. max = 90.
gives the mixing angle theta_PS in the pseudoscalar meson sector
(which is rather poorly determined), expressed in degrees.
Here f is associated with eta' and f' with eta. (This standard
but counterintuitive choice is fixed up in the code by replacing
alpha -> 90 degrees - alpha so that eta <-> eta'; relative signs do
not matter since we are interested in probabilities only.)

<parameter> StringFlav:thetaV = 36. min = -90. max = 90.
gives the mixing angle theta_V in the vector meson sector
(which is somewhat better determined), expressed in degrees.
Here f is associated with omega and f' with phi.

Further, it appears that the model overestimates the production 
of eta and, in particular, eta' mesons, which can be rectified by 

<parameter> StringFlav:suppressEta = 1.0 min = 0. max = 1.
<parameter> StringFlav:suppressEtaPrime = 0.4 min = 0. max = 1.
the additional suppression of eta and eta' production, respectevely,
multiplying the normal production probability.

The relative rate of baryon production is mainly given by the quark
and diquark production parameters plus SU(6) Clebsch-Gordans. The
only extra modifiable parameter is

<parameter> StringFlav:suppressDecuplet = 1.0 min = 0.0 max = 1.0
the suppression, relative to default SU(6) factors, of decuplet 
baryon production.
 
---------------------------------------------------------------------- 

   The StringZ class
   -----------------

This class handles the choice of longitudinal lightcone fraction z
according to one of two possible shape sets.

The Lund symmetric fragmentation function [1] is the only alternative 
for light quarks. It is of the form 
     f(z) = (1/z) * (1-z)^a * exp(-b m_T^2 / z)
with the two main free parameters a and b to be tuned to data.
They are stored in 

<parameter> StringZ:aLund = 0.3 min = 0.0 max = 2.0
<parameter> StringZ:bLund = 0.58 min = 0.2 max = 2.0

In principle, each flavour can have a different a. Then for going 
from an old flavour i to a new j one the shape is 
     f(z) = (1/z) * z^{a_i} * ((1-z)/z)^{a_j} * exp(-b * m_T^2 / z)
This is only implemented for diquarks relative to normal quarks:
<parameter> StringZ:aExtraDiquark 0.5 min = 0.0 max = 2.0
allows a larger a for diquarks, with total a = aLund + aExtraDiquark.

Finally, the Bowler modification [3] introduces an extra factor
     1/z^{r_Q * b * m_Q^2)
for heavy quarks. To keep some flexibility, a multiplicative factor
r_Q is introduced, which ought to be unity but can be set in

<parameter> StringZ:rFactC = 1.0 min = 0.0 max = 2.0
<parameter> StringZ:rFactB = 1.0 min = 0.0 max = 2.0
<parameter> StringZ:rFactH = 1.0 min = 0.0 max = 2.0

separately for charm, bottom and heavier hadrons. (The heavier here
represents any new coloured particle long-lived enough to hadronize,
say in some supersymmetric scenario.)

As an alternative, it is possible to switch over to the 
Peterson/SLAC formula [4]
     f(z) = 1 / ( z * (1 - 1/z - epsilon/(1-z))^2 )
for charm, bottom and heavier (defined as above) by the three

<flag> StringZ:usePetersonC off
<flag> StringZ:usePetersonB off
<flag> StringZ:usePetersonH off

When switched on, the corresponding epsilon value is read off from

<parameter> StringZ:epsilonC = 0.05 min = 0.01 max = 0.25
<parameter> StringZ:epsilonB = 0.005 min = 0.001 max = 0.025
<parameter> StringZ:epsilonH = 0.005 min = 0.0001 max = 0.25

Since the last case represents a particle with unknown mass, the value 
we give is the one that would be used for m_H = m_b, which then is
rescaled by a factor (m_b^2 / m_H^2) to obtain the actually used epsilon.

---------------------------------------------------------------------- 

   The StringPT class
   ------------------

This class handles the choice of fragmentation pT. 
At each string breaking the quark and antiquark of the pair are
supposed to receive opposite and compensating pT kicks according
to a Gaussian distribution in px and py separately. Call sigma_q 
the width of the p_x and p_y distributions separately, i.e.
d(Prob) = exp( -(p_x^2 + p_y^2) / 2 sigma_q^2).
Then the total width^2 is 
<pT^2> = <p_x^2> +  <p_y^2> = 2 sigma_q^2 = sigma^2.
It is this latter number that is stored in

<parameter> StringPT:sigma = 0.36 min = 0.0 max = 1.0

Since a normal hadron receives pT contributions for two string 
breakings, it has a <p_x^2>_had = <p_y^2>_had = sigma^2, and 
thus <pT^2>_had = 2 sigma^2.  

Some studies on isolated particles at LEP has indicated the need for 
a slightly enhanced rate in the high-pT tail of the above distribution.
This would have to be reviewed in the context of a complete retune of
parton showers and hadronization, but for the moment we stay with
the current recipe, to boost the above pT by a factor enhancedWidth
for a small fraction enhancedFraction of the breakups, where

<parameter> StringPT:enhancedFraction = 0.1 min = 0.0 max = 0.1
<parameter> StringPT:enhancedWidth = 2.0 min = 1.0 max = 5.0
   
---------------------------------------------------------------------- 

References
 
[1] B. Andersson, G. Gustafson, G. Ingelman and T. Sjostrand,
    Phys. Rep. 97 (1983) 31

[2] Particle Data Group, S. Eidelman et al., 
    Phys. Lett. B592 (2004) 1

[3] M.G. Bowler, Z. Phys. C11 (1981) 169

[4] C. Peterson, D. Schlatter, I. Schmitt and P. Zerwas, 
    Phys. Rev. D27 (1983) 105

---------------------------------------------------------------------- 

Copyright C 2006 Torbjorn Sjostrand
